#!/usr/bin/env python
# -*- coding:utf-8 -*-

from setuptools import setup, find_packages

setup(
    name="ml-scrapy",
    version="0.0.2",
    keywords=("pip", "scrapy"),
    description="Components For Scrapy Project",
    long_description="Components For Scrapy Project",
    license="MIT Licence",

    url="https://github.com/mic1on/ml-scrapy",
    author="miclon",
    author_email="jcnd@163.com",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
)
